==> kita-0.150.0.tar.gz: kita-0.150.0/kita/src/libkita/kita-utf8.h <==
/**************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
*   ikemo@wakaba.jp                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
**************************************************************************/

/* UTF-8 japanese strings  */

#define KITAUTF8_ZENSPACE "　"
#define KITAUTF8_EXTRACT "抽出"
#define KITAUTF8_NOWRENEW " 更新中・・・"
#define KITAUTF8_NOWEXPAND " 展開中・・・"
#define KITAUTF8_INCACHE "キャッシュ済"
#define KITAUTF8_KOKOYON  "ここまで読んだ"
#define KITAUTF8_KOKOYON2 "──────────ここまで読んだ──────────"
#define KITAUTF8_TEMPLATE "──────────テンプレート──────────"
#define KITAUTF8_COLON "："
#define KITAUTF8_BTITLE "板看板"
#define KITAUTF8_NAME "名前："
#define KITAUTF8_ZENBU  "全部"
#define KITAUTF8_ZENBUNOKORI  "残り全部"
#define KITAUTF8_TUGI100 "次100"
#define KITAUTF8_ZENBUMAE  "前全部"
#define KITAUTF8_MAE100 "前100"
#define KITAUTF8_SAIGO  "最後"
#define KITAUTF8_KOWARE   "ここは壊れています。"
#define KITAUTF8_ABONE  "あぼ〜ん"
#define KITAUTF8_GOTO  "移動"
#define KITAUTF8_FRAME1 "│"
#define KITAUTF8_FRAME2 "├"
#define KITAUTF8_FRAME3 "└"

#define KITAUTF8_HEART    "♥"
#define KITAUTF8_DIA      "♦"
#define KITAUTF8_CLUB     "♣"
#define KITAUTF8_SPADE    "♠"

==> kita-0.170.0.tar.gz: kita-0.170.0/kita/src/libkita/kita-utf8.h <==
/**************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
*   ikemo@wakaba.jp                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
**************************************************************************/

/* UTF-8 japanese strings  */

#define KITAUTF8_ZENSPACE "　"
#define KITAUTF8_EXTRACT "抽出"
#define KITAUTF8_NOWRENEW " 更新中・・・"
#define KITAUTF8_NOWEXPAND " 展開中・・・"
#define KITAUTF8_INCACHE "キャッシュ済"
#define KITAUTF8_KOKOYON  "ここまで読んだ"
#define KITAUTF8_KOKOYON2 "──────────ここまで読んだ──────────"
#define KITAUTF8_TEMPLATE "──────────テンプレート──────────"
#define KITAUTF8_COLON "："
#define KITAUTF8_BTITLE "板看板"
#define KITAUTF8_NAME "名前："
#define KITAUTF8_ZENBU  "全部"
#define KITAUTF8_ZENBUNOKORI  "残り全部"
#define KITAUTF8_TUGI100 "次100"
#define KITAUTF8_ZENBUMAE  "前全部"
#define KITAUTF8_MAE100 "前100"
#define KITAUTF8_SAIGO  "最後"
#define KITAUTF8_KOWARE   "ここは壊れています。"
#define KITAUTF8_ABONE  "あぼーん"
#define KITAUTF8_GOTO  "移動"
#define KITAUTF8_FRAME1 "│"
#define KITAUTF8_FRAME2 "├"
#define KITAUTF8_FRAME3 "└"

#define KITAUTF8_HEART    "♥"
#define KITAUTF8_DIA      "♦"
#define KITAUTF8_CLUB     "♣"
#define KITAUTF8_SPADE    "♠"

#define  KITAUTF8_MONDAY "（月）"
#define  KITAUTF8_TUESDAY "（火）"
#define  KITAUTF8_WEDNESDAY "（水）"
#define  KITAUTF8_THURSDAY "（木）"
#define  KITAUTF8_FRIDAY "（金）"
#define  KITAUTF8_SATURDAY "（土）"
#define  KITAUTF8_SUNDAY "（日）"
